==> Evergreen-ILS-3.14.7.tar.gz: Evergreen-ILS-3.14.7/Open-ILS/web/js/dojo/openils/opac/nls/tr-tr/opac.js <==
{
    ":BARCODE_PROMPT": "barkod: ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "Cancel",
    ":SUBMIT_BUTTON_LABEL": "Submit",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Password reset response",
    ":PWD_RESET_SUBMIT_SUCCESS": "Parola s\u0131f\u0131rlama i\u015flemine ba\u015flamak i\u00e7in iste\u011finiz i\u015flendi. Hesab\u0131n\u0131z\u0131n ge\u00e7erli bir e-posta adresi varsa, yak\u0131nda \u015fifrenizi s\u0131f\u0131rlamak i\u00e7in ayr\u0131nt\u0131l\u0131 talimatlar i\u00e7eren bir e-posta almak gerekir.",
    ":PWD_RESET_SUBMIT_ERROR": "The system could not process your request for a password reset. Please try again, or contact circulation staff for assistance.",
    ":PWD_RESET_SUBMIT_STATUS": "Sending request...",
    ":PWD_RESET_FORGOT_PROMPT": "Forgot your password?",
    ":PWD_RESET_FORM_TITLE": "\u015eifre s\u0131f\u0131rlama iste\u011fi",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "MHFD Kayd\u0131 Ekle",
    ":CREATED_MFHD_RECORD": "${0} \u0130\u00e7in MHFD Kay\u0131tlar\u0131",
    ":DELETE_MFHD": "Kayd\u0131 Sil",
    ":DELETE_MFHD_CONFIRM": "Bu seri kayd\u0131 silmek istedi\u011finizden emin m\u0131s\u0131n\u0131z?",
    ":DELETED_MFHD_RECORD": "Silinmi\u015f MFHD kay\u0131t $ {0}",
    ":EDIT_MFHD_RECORD": "Kay\u0131tlar\u0131 De\u011fi\u015ftir",
    ":EDIT_MFHD_MENU": "Edit Holdings",
    ":EDIT_PROPERTIES": "Edit Properties",
    ":BASIC_HOLDINGS": "Volumes",
    ":BASIC_HOLDINGS_ADD": "Additional Volume Information",
    ":INDEX_HOLDINGS": "Indexes",
    ":INDEX_HOLDINGS_ADD": "Additional Index Information",
    ":CURRENT_HOLDINGS": "Ge\u00e7erli cilt",
    ":CURRENT_INDEXES": "g\u00fcncel indeksler",
    ":CURRENT_SUPPLEMENTS": "Mevcut Eklentiler",
    ":HOLDINGS_TABLE_CAPTION": "Holdings summary (${0})",
    ":INCOMPLETE_VOLUMES": "Incomplete volumes",
    ":MISSING_VOLUMES": "Eksik disk b\u00f6l\u00fcmleri",
    ":ONLINE_VOLUMES": "Online volumes",
    ":SAVE_MFHD_LABEL": "MFHD Kaydet",
    ":SUPPLEMENT_HOLDINGS": "Takviyeler",
    ":SUPPLEMENT_HOLDINGS_ADD": "Additional Supplement Information",
    ":PLACE_HOLD": "Place hold",
    ":HOLD_STATUS_PLURAL": "hold # ${0} of ${1} total holds and ${2} potential items",
    ":HOLD_STATUS_SINGULAR": "hold # ${0} of ${1} total holds and ${2} potential item",
    ":MORE": "More",
    ":MORE_COPIES_FULL_RECORD": "... more copies listed in full record",
    ":SOURCE_CANNOT_HAVE_COPIES": "Records from ${0} cannot have copies."
}

==> Evergreen-ILS-3.16.1.tar.gz: Evergreen-ILS-3.16.1/Open-ILS/web/js/dojo/openils/opac/nls/tr-tr/opac.js <==
{
    ":BARCODE_PROMPT": "barkod: ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "Cancel",
    ":SUBMIT_BUTTON_LABEL": "Submit",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Password reset response",
    ":PWD_RESET_SUBMIT_SUCCESS": "Parola s\u0131f\u0131rlama i\u015flemine ba\u015flamak i\u00e7in iste\u011finiz i\u015flendi. Hesab\u0131n\u0131z\u0131n ge\u00e7erli bir e-posta adresi varsa, yak\u0131nda \u015fifrenizi s\u0131f\u0131rlamak i\u00e7in ayr\u0131nt\u0131l\u0131 talimatlar i\u00e7eren bir e-posta almak gerekir.",
    ":PWD_RESET_SUBMIT_ERROR": "The system could not process your request for a password reset. Please try again, or contact circulation staff for assistance.",
    ":PWD_RESET_SUBMIT_STATUS": "Sending request...",
    ":PWD_RESET_FORGOT_PROMPT": "Forgot your password?",
    ":PWD_RESET_FORM_TITLE": "\u015eifre s\u0131f\u0131rlama iste\u011fi",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "MHFD Kayd\u0131 Ekle",
    ":CREATED_MFHD_RECORD": "${0} \u0130\u00e7in MHFD Kay\u0131tlar\u0131",
    ":DELETE_MFHD": "Kayd\u0131 Sil",
    ":DELETE_MFHD_CONFIRM": "Bu seri kayd\u0131 silmek istedi\u011finizden emin m\u0131s\u0131n\u0131z?",
    ":DELETED_MFHD_RECORD": "Silinmi\u015f MFHD kay\u0131t $ {0}",
    ":EDIT_MFHD_RECORD": "Kay\u0131tlar\u0131 De\u011fi\u015ftir",
    ":EDIT_MFHD_MENU": "Edit Holdings",
    ":EDIT_PROPERTIES": "\u00d6zellikleri D\u00fczenle",
    ":BASIC_HOLDINGS": "Volumes",
    ":BASIC_HOLDINGS_ADD": "Additional Volume Information",
    ":INDEX_HOLDINGS": "Indexes",
    ":INDEX_HOLDINGS_ADD": "Additional Index Information",
    ":CURRENT_HOLDINGS": "Ge\u00e7erli cilt",
    ":CURRENT_INDEXES": "g\u00fcncel indeksler",
    ":CURRENT_SUPPLEMENTS": "Mevcut Eklentiler",
    ":HOLDINGS_TABLE_CAPTION": "Holdings summary (${0})",
    ":INCOMPLETE_VOLUMES": "Incomplete volumes",
    ":MISSING_VOLUMES": "Eksik disk b\u00f6l\u00fcmleri",
    ":ONLINE_VOLUMES": "Online volumes",
    ":SAVE_MFHD_LABEL": "MFHD Kaydet",
    ":SUPPLEMENT_HOLDINGS": "Takviyeler",
    ":SUPPLEMENT_HOLDINGS_ADD": "Additional Supplement Information",
    ":PLACE_HOLD": "Place hold",
    ":HOLD_STATUS_PLURAL": "hold # ${0} of ${1} total holds and ${2} potential items",
    ":HOLD_STATUS_SINGULAR": "hold # ${0} of ${1} total holds and ${2} potential item",
    ":MORE": "More",
    ":MORE_COPIES_FULL_RECORD": "... more copies listed in full record",
    ":SOURCE_CANNOT_HAVE_COPIES": "Records from ${0} cannot have copies."
}
